{
    "$graph": [
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "label": "BAM files",
                    "doc": "Array of input BAM files",
                    "id": "#main/bam_file"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "int"
                    },
                    "label": "Fragment sizes",
                    "doc": "Array of fragment sizes",
                    "id": "#main/fragment_size"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "int"
                    },
                    "label": "Total reads numbers",
                    "doc": "Array of total reads number for downstream normalization",
                    "id": "#main/total_reads"
                }
            ],
            "steps": [
                {
                    "run": "#homer-make-tag-directory.cwl",
                    "in": [
                        {
                            "source": "#main/bam_file",
                            "id": "#main/make_tag_directory/bam_file"
                        },
                        {
                            "source": "#main/fragment_size",
                            "id": "#main/make_tag_directory/fragment_size"
                        },
                        {
                            "source": "#main/total_reads",
                            "id": "#main/make_tag_directory/total_reads"
                        }
                    ],
                    "scatter": [
                        "#main/make_tag_directory/bam_file",
                        "#main/make_tag_directory/fragment_size",
                        "#main/make_tag_directory/total_reads"
                    ],
                    "scatterMethod": "dotproduct",
                    "out": [
                        "#main/make_tag_directory/output_tag_folder"
                    ],
                    "id": "#main/make_tag_directory"
                }
            ],
            "doc": "Workflow runs homer-make-tag-directory.cwl tool using scatter for the following inputs\n  - bam_file\n  - fragment_size\n  - total_reads\n\n`dotproduct` is used as a `scatterMethod`, so one element will be taken from each array to construct each job:\n  1) bam_file[0] fragment_size[0] total_reads[0]\n  2) bam_file[1] fragment_size[1] total_reads[1]\n     ...\n  N) bam_file[N] fragment_size[N] total_reads[N]\n\n`bam_file`, `fragment_size` and `total_reads` arrays should have the identical order.\n",
            "id": "#main",
            "http://schema.org/name": "heatmap-prepare",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/workflows/heatmap-prepare.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        },
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Andrey Kartashov",
                                            "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0001-9102-5681"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Runs homer-make-tag-directory.cwl with the scatter using dot product of the inputs bam_file, fragment_size and total_reads.\n",
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "label": "Tag directories",
                    "doc": "Array of tag directories",
                    "outputSource": "#main/make_tag_directory/output_tag_folder",
                    "id": "#main/tag_folder"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": "${\n  return [\n    {\"class\": \"Directory\",\n     \"basename\": \"default\",\n     \"listing\": [inputs.bam_file],\n     \"writable\": true}\n  ]\n}\n"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/homer:v0.0.2"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "Alignment file, BAM",
                    "id": "#homer-make-tag-directory.cwl/bam_file"
                },
                {
                    "type": [
                        "null",
                        "int",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-fragLength"
                    },
                    "doc": "Set fragment size.\nBy default is estimated as if it was single end ChIP-Seq experiment.\nPossible values:\n  \"#\" - int value to be used as fragment size\n  \"given\" - use read lengths\n  \"pe\" - calculate from paired end read coordinates\n",
                    "id": "#homer-make-tag-directory.cwl/fragment_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "-maxlen"
                    },
                    "doc": "Discard reads bigger then\n",
                    "id": "#homer-make-tag-directory.cwl/max_length"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-minlen"
                    },
                    "doc": "Discard reads smaller then\n",
                    "id": "#homer-make-tag-directory.cwl/min_length"
                },
                {
                    "type": [
                        "null",
                        "int",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-totalReads"
                    },
                    "doc": "Set total reads number for downstream normalization.\nDefault: autocalculated, equal to uniquely mapped reads number\nPossible values:\n  \"#\" - int value to be used as total reads number\n  \"all\" - autocalculated, equal to uniquely + multi mapped reads number\n",
                    "id": "#homer-make-tag-directory.cwl/total_reads"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.bam_file.basename.split('.')[0])"
                    },
                    "doc": "Tag directory",
                    "id": "#homer-make-tag-directory.cwl/output_tag_folder"
                }
            ],
            "baseCommand": [
                "makeTagDirectory"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.bam_file.basename.split('.')[0])"
                },
                {
                    "valueFrom": "$(\"default/\" + inputs.bam_file.basename)"
                }
            ],
            "doc": "Tool runs makeTagDirectory that basically parses through the alignment file and splits the tags into separate\nfiles based on the chromosomes.\n\nMultiple alignment files are not supported. Alignment file's format is restricted to be only BAM.\n\nOutput is placed in a folder with the name derived from the input BAM file's basename.\n\nSkipped arguments:\n\n  Rely on the default value:\n    -format           - format will be autodetected\n    -precision        - the default value is used\n\n  Not required general functionality:\n    -d\n    -single\n    -force5th\n    -t\n    -flip\n    -tbp\n\n  Not required GC-bias options:\n    -genome\n    -checkGC\n    -normGC\n    -normFixedOligo\n    -minNormRatio\n    -maxNormRatio\n    -iterNorm\n    -filterReads\n\n  Not required HiC options:\n    -removePEbg\n    -restrictionSite\n    -removeSpikes\n    -bowtiePE\n    -directional\n",
            "id": "#homer-make-tag-directory.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#homer-metadata.yaml",
                "http://schema.org/name": "Homer",
                "http://schema.org/about": "HOMER (Hypergeometric Optimization of Motif EnRichment)"
            },
            "http://schema.org/name": "homer-make-tag-directory",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/homer-make-tag-directory.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage:\n  makeTagDirectory <directory> <alignment file 1> [file 2] ... [options]\n\n      Creates a platform-independent 'tag directory' for later analysis.\n      Currently BED, eland, bowtie, and sam files are accepted. The program will try to\n      automatically detect the alignment format if not specified.  Program will also\n      unzip *.gz, *.bz2, and *.zip files and convert *.bam to sam files on the fly\n      Existing tag directories can be added or combined to make a new one using -d/-t\n      If more than one format is needed and the program cannot auto-detect it properly,\n      make separate tag directories by running the program separately, then combine them.\n      To perform QC/manipulations on an existing tag directory, add \"-update\"\n\n      Options:\n          -fragLength <# | given | pe> (Set estimated fragment length or use PE length - given: use read lengths)\n              By default treats the sample as a single read ChIP-Seq experiment\n          -format <X> where X can be: (with column specifications underneath)\n              bed - BED format files:\n                  (1:chr,2:start,3:end,4:+/- or read name,5:# tags,6:+/-)\n                  -force5th (5th column of BED file contains # of reads mapping to position)\n              sam - SAM formatted files (use samTools to covert BAMs into SAM if you have BAM)\n                  -unique (keep if there is a single best alignment based on mapq)\n                      -mapq <#> (Minimum mapq for -unique, default: 10, set negative to use AS:i:/XS:i:)\n                  -keepOne (keep one of the best alignments even if others exist)\n                  -keepAll (include all alignments in SAM file)\n                  -mis (Maximum allowed mismatches, default: no limit, uses MD:Z: tag)\n                  -sspe (strand specific, paired-end reads[flips strand of 2nd read to match])\n                  -read1/-read2 (only analyze 1st or 2nd read for PE sequencing)\n              bowtie - output from bowtie (run with --best -k 2 options)\n                  (1:read name,2:+/-,3:chr,4:position,5:seq,6:quality,7:NA,8:misInfo)\n              eland_result - output from basic eland\n                  (1:read name,2:seq,3:code,4:#zeroMM,5:#oneMM,6:#twoMM,7:chr,\n                              8:position,9:F/R,10-:mismatches\n              eland_export - output from illumina pipeline (22 columns total)\n                  (1-5:read name info,9:sequence,10:quality,11:chr,13:position,14:strand)\n              eland_extended - output from illumina pipeline (4 columns total)\n                  (1:read name,2:sequence,3:match stats,4:positions[,])\n              mCpGbed - encode style mCpG reporting in extended BED format, no auto-detect\n                  (1:chr,2:start,3:end,4:name,5:,6:+/-,7:,8:,9:,10:#C,11:#mC)\n              allC - Lister style output files detailing the read information about all cytosines\n                  (1:chr,2:pos,3:strand,4:context,#mC,#totalC,#unmC\n              bismark - Bismark style output files detailing the read information about all cytosines\n                  (1:chr,2:pos,3:strand,4:#mC,5:#unmC,6:context,7:triseq\n                  -minCounts <#> (minimum number of reads to report mC/C ratios, default: 10)\n                  -mCcontext <CG|CHG|CHH|all> (only use C's in this context, default: CG)\n              HiCsummary - minimal paired-end read mapping information\n                  (1:readname,2:chr1,3:5'pos1,4:strand1,5:chr2,6:5'pos2,7:strand2)\n          -flip (flip strand of each read, i.e. might want to use with some RNA-seq)\n          -totalReads <#|all|default> (set the effective total number of reads - all includes multimappers)\n          -force5th (5th column of BED file contains # of reads mapping to position)\n          -d <tag directory> [tag directory 2] ... (add Tag directory to new tag directory)\n          -t <tag file> [tag file 2] ... (add tag file i.e. *.tags.tsv to new tag directory)\n          -single (Create a single tags.tsv file for all \"chromosomes\" - i.e. if >100 chromosomes)\n          -update (Use current tag directory for QC/processing, do not parse new alignment files)\n          -tbp <#> (Maximum tags per bp, default: no maximum)\n          -precision <1|2|3> (number of decimal places to use for tag totals, default: 1)\n          -minlen <#> and -maxlen <#> (Filter reads with lengths outside this range)\n\n          GC-bias options:\n          -genome <genome version> (To see available genomes, use \"-genome list\")\n              -or- (for custom genomes):\n          -genome <path-to-FASTA file or directory of FASTA files>\n\n          -checkGC (check Sequence bias, requires \"-genome\")\n              -freqStart <#> (offset to start calculating frequency, default: -50)\n              -freqEnd <#> (distance past fragment length to calculate frequency, default: +50)\n              -oligoStart <#> (oligo bias start)\n              -oligoEnd <#> (oligo bias end)\n          -normGC <target GC profile file> (i.e. tagGCcontent.txt file from control experiment)\n              Use \"-normGC default\" to match the genomic GC distribution\n          -normFixedOligo <oligoFreqFile> (normalize 5' end bias, \"-normFixedOligo default\" ok)\n          -minNormRatio <#> (Minimum deflation ratio of tag counts, default: 0.25)\n          -maxNormRatio <#> (Maximum inflation ratio of tag counts, default: 2.0)\n          -iterNorm <#> (Sets -max/minNormRatio to 1 and 0, iteratively normalizes such that the\n              resulting distrubtion is no more than #% different than target, i.e. 0.1,default: off)\n          -filterReads <seq> <offset> <keep|remove> (filter reads based on oligo sequence in the genome)\n\n      HiC options\n          -removePEbg (remove paired end tags within 1.5x fragment length on same chr)\n              -PEbgLength <#> (remove PE  reads facing on another within this distance, default: 1.5x fragLen)\n          -restrictionSite <seq> (i.e. AAGCTT for HindIII, assign data < 1.5x fragment length to sites)\n              Must specify genome sequence directory too. (-rsmis <#> to specify mismatches, def: 0)\n              -both, -one, -onlyOne, -none (Keeps reads near restriction sites, default: keep all)\n              -removeSelfLigation (removes reads linking same restriction fragment)\n              -removeRestrictionEnds (removes reads starting on a restriction fragment)\n              -assignMidPoint (will place reads in the middle of HindIII fragments)\n              -restrictionSiteLength <#> (maximum distance from restriction site, default: 1.5x fragLen)\n          -removeSpikes <size bp> <#> (remove tags from regions with > than # times\n              the average tags per size bp, suggest \"-removeSpikes 10000 8\")\n          -bowtiePE (PE alignments in bowtie alignment, assumes last character of read name is 0 or 1)\n              (don't need this for sam/bam files)\n          -directional (matrix is not symetric, i.e. grid-seq, 1st/2nd read mean something)"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://github.com/schemaorg/schemaorg/raw/main/data/releases/11.01/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
